#ifndef _AIC_H_
#define _AIC_H_
#define AICTEST
/*------------------------------------------------------
 Maximum likelihood estimation 
 of migration rate  and effectice population size
 using a Metropolis-Hastings Monte Carlo algorithm                            
 -------------------------------------------------------                        
 aic model  test   R O U T I N E S 
 
 Peter Beerli 2001, Seattle
 beerli@csit.fsu.edu
 
Copyright 2001 Peter Beerli and Joseph Felsenstein
 
$Id: aic.h,v 1.8 2003/11/04 16:12:08 beerli Exp $
-------------------------------------------------------*/
#include "migration.h"

extern void akaike_information (world_fmt * world, long *Gmax);
extern long find_paramnum(world_fmt *world, char *connect);

#endif
